from supportive_functions import generate_female_name, generate_male_name, generate_surname


female_prefix = [
    "bal", "da", "din", "dur", "fal", "gim", "gin", "gor", "hel", "in", "kil", "li", "mha", "na",
    "nin", "ran", "sha", "thor", "tha", "zin"
]

female_suffix = [
    "ǎ", "dǎ", "del", "dûr", "fa", "ga", "gal", "gan", "gard", "hild", "in", "kil", "la", "lda",
    "lin", "ma", "mi", "na", "ra", "ri", "sa", "thi", "thra", "zǎ"
]


male_prefix = [
    "az", "bal", "bor", "da", "dor", "du", "fa", "gar", "gim", "glo", "gra", "grom", "han", "hur",
    "kaz", "kil", "knar", "kri", "lur", "mak", "mor", "nar", "nor", "ri", "rok", "run", "thor",
    "thra", "thu", "ul", "ur", "var", "vōr"
]

male_suffix = [
    "ain", "ǎk", "ar", "bar", "bor", "dain", "dal", "din", "dûr", "fin", "gǎrn", "gar", "gim",
    "gorn", "grim", "gûn", "gûr", "in", "kil", "korn", "li", "lin", "mar", "mir", "nar", "nûr",
    "rik", "rim", "rin", "ron", "rum", "thōr", "thrin", "thûr", "um", "ûr", "var", "zin"
]


surname_syllables = [
    'bar', 'bif', 'bin', 'bor', 'bǎl', 'dal', 'dar', 'dur', 'fal', 'fin', 'gar', 'gim', 'gin', 'gon',
    'gor', 'grim', 'gun', 'gur', 'har', 'kar', 'kaz', 'khaz', 'kil', 'kin', 'kram', 'kōr', 'lok',
    'lor', 'mag', 'mak', 'mar', 'mir', 'mur', 'nar', 'nim', 'nor', 'nûr', 'rag', 'rig', 'rik', 'rim',
    'ror', 'rum', 'tar', 'thar', 'thor', 'thrak', 'thran', 'thrur', 'tor', 'tur', 'ur', 'vol', 'vor'
]

female = generate_female_name(female_prefix, female_suffix, min=1, max=2)
male = generate_male_name(male_prefix, male_suffix, min=0, max=1)
surname = generate_surname(surname_syllables)



from supportive_functions import generate_female_name, generate_male_name, generate_surname_less


female_prefix = [
    "ber", "bri", "cla", "cor", "dal", "dor", "el", "fro", "gol", "har", "hil", "lav", "lil", "lo",
    "mar", "mel", "nar", "nor", "ol", "per", "pip", "ro", "sam", "san", "syl", "tas", "wil",
]

female_suffix = [
    "a", "adoc", "ald", "bella", "belle", "dora", "ella", "elle", "freda", "gwen", "la", "lea",
    "lina", "lla", "lotta", "ma", "mia", "mina", "mira", "na", "nelle", "nna", "ra", "ri", "ria",
    "rie", "rina", "sa", "sella", "sie", "sy", "ta", "tina", "wyn",
]

male_prefix = [
    "albo", "bal", "bil", "bran", "con", "dodo", "ever", "fal", "fer", "fin", "gaf", "gim", "gol",
    "ham", "hob", "las", "leo", "lim", "lobo", "mar", "milo", "mung", "nico", "odo", "olbo", "pal",
    "per", "pim", "pip", "rolo", "ruf", "sam", "silbo", "tob", "ugo", "vigo", "wigo", "wim", "wise",
    "wolbo",
]

male_suffix = [
    "bo", "bri", "do", "dro", "fast", "fer", "gar", "go", "grin", "hard", "lo", "man", "mo", "nac",
    "nard", "nibo", "no", "per", "pin", "po", "ric", "rim", "ro", "san", "sim", "to", "wise",
]

surname_prefix =  [
    "bagg", "bran", "bur", "cra", "cud", "good", "green", "hard", "hay", "hill", "le", "long",
    "merry", "oak", "old", "pere", "pip", "proud", "sack", "small", "tall", "took", "toss",
    "under", "whit",
]

surname_suffix = [
    "bottom", "buckle", "burr", "by", "digger", "foot", "girdle", "hair", "hobb", "ins",
    "kins", "leaf", "man", "over", "pint", "root", "shire", "thistle", "top", "wag", "ward",
    "wheat", "wort", "worthy",
]

female = generate_female_name(female_prefix, female_suffix, min=1, max=1)
male = generate_male_name(male_prefix, male_suffix, min=1, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)


from random import choice
from supportive_functions import generate_surname_less


female_names = [
    "Adelaide",
    "Adriana",
    "Amara",
    "Amaryllis",
    "Anastasia",
    "Arabella",
    "Ariadne",
    "Arianwen",
    "Astoria",
    "Aurelia",
    "Brielle",
    "Calliope",
    "Cassandra",
    "Celestia",
    "Cressida",
    "Dahlia",
    "Elara",
    "Eleanor",
    "Elowen",
    "Elysia",
    "Emmeline",
    "Evaine",
    "Evangeline",
    "Evelina",
    "Fiona",
    "Fiora",
    "Genevieve",
    "Ginevra",
    "Giselle",
    "Guinevere",
    "Gwendolyn",
    "Helena",
    "Helene",
    "Iliana",
    "Imelda",
    "Isabeau",
    "Isolde",
    "Jessamine",
    "Jocelyn",
    "Lavinia",
    "Lorelei",
    "Lyra",
    "Maelisande",
    "Marigold",
    "Melisande",
    "Mirella",
    "Morgana",
    "Morwenna",
    "Nerissa",
    "Octavia",
    "Ophelia",
    "Oriana",
    "Pandora",
    "Persephone",
    "Quintessa",
    "Ravenna",
    "Rosalind",
    "Rosamund",
    "Rowena",
    "Sabrina",
    "Selene",
    "Seraphina",
    "Seraphine",
    "Sylvana",
    "Tatiana",
    "Thalia",
    "Titania",
    "Ursula",
    "Vespera",
    "Viola",
    "Vivienne",
    "Wilhelmina",
    "Winifred",
    "Xanthe",
    "Yara",
    "Yvette",
    "Zephyrine",
]

male_names = [
    "Arthur",
    "Lancelot",
    "Gawain",
    "Tristan",
    "Gareth",
    "Percival",
    "Galahad",
    "Lysander",
    "Valerian",
    "Benedict",
    "Cedric",
    "Edric",
    "Finnian",
    "Hector",
    "Leander",
    "Theobald",
    "Ambrose",
    "Dorian",
    "Edmund",
    "Frederick",
    "Gerard",
    "Harold",
    "Jareth",
    "Luther",
    "Merrick",
    "Oswald",
    "Reginald",
    "Sylvester",
    "Tristram",
    "Ulric",
    "Wilfred",
    "Caius",
    "Emeric",
    "Gideon",
    "Hadrian",
    "Jasper",
    "Leopold",
    "Maximilian",
    "Oberon",
    "Quentin",
    "Roderick",
    "Sebastian",
    "Thaddeus",
    "Ulysses",
    "Victor",
    "Xander",
    "Yorick",
    "Zephyr",
    "Balthazar",
    "Cassius",
    "Dominic",
    "Ezekiel",
    "Felix",
    "Gareth",
    "Horatio",
    "Ignatius",
    "Jeremiah",
    "Kieran",
    "Lazarus",
    "Magnus",
    "Nathaniel",
    "Orlando",
    "Peregrine",
    "Quirinus",
    "Raphael",
    "Solomon",
    "Theron",
    "Uriah",
    "Vance",
    "Winston",
    "Xavier",
    "Yale",
    "Zacharias",
]

surname_prefix = [
    "amber",
    "black",
    "blade",
    "blaze",
    "blood",
    "bright",
    "dark",
    "dawn",
    "dragon",
    "dusk",
    "fire",
    "frost",
    "golden",
    "hawk",
    "iron",
    "mist",
    "moon",
    "night",
    "oak",
    "raven",
    "shadow",
    "silver",
    "star",
    "steel",
    "stone",
    "storm",
    "swift",
    "sword",
    "thorn",
    "thunder",
    "valiant",
    "white",
    "wind",
    "winter",
    "wolf"
]

surname_suffix = [
    "shard",
    "scale",
    "sword",
    "thistle",
    "thorn",
    "walker",
    "wind",
    "fire",
    "moon",
    "raven",
    "rider",
    "blade",
    "flame",
    "wing",
    "wood",
    "bane",
    "storm",
    "shadow",
    "dusk",
    "fall",
    "hawk",
    "bark",
    "fang",
    "fist",
    "foot",
    "helm",
    "mist",
    "stone",
    "beard",
    "weaver",
    "shadow",
    "shield",
    "spear",
    "leaf",
    "mantle",
    "eye",
    "claw",
    "caster",
    "vale",
    "blood",
    "brook",
    "song",
    "thorn",
    "wing",
    "fire",
    "shield",
    "heart",
    "thistle",
    "thorn",
    "shadow",
    "wood",
    "bane",
    "blade",
    "caster",
    "claw",
    "fall",
    "fire",
    "heart",
    "storm",
    "thorn",
    "vale",
    "brook",
    "shield",
    "spear",
    "stone",
    "thistle",
    "thorn",
    "wing",
    "fire",
    "shield",
    "heart",
    "song",
    "spear",
    "sword",
    "warden",
    "watch",
    "arrow",
    "brook",
    "foot",
    "steel",
    "strike",
    "wind",
    "breaker",
    "field",
    "heart",
    "thunder",
    "strike",
    "heart",
    "thorn",
    "storm",
    "bane"
]

female = choice(female_names)
male = choice(male_names)
surname = generate_surname_less(surname_prefix, surname_suffix)



from supportive_functions import generate_female_name, generate_male_name, generate_surname_less


female_prefix = [
    "ar", "bal", "bar", "bran", "dar", "dran", "feth", "gras", "har", "jaf", "kar", "krul",
    "mar", "nar", "par", "rak", "ras", "sar", "tar", "thas", "thul", "war", "yas", "zar"
]


female_suffix = [
    "a", "ah", "al", "an", "ar", "ara", "as", "ath", "aun", "aya", "az", "da", "dal", "dan",
    "dar", "de", "del", "din", "dra", "du", "dul", "e", "eh", "el", "en", "er", "eth", "i",
    "ia", "il", "in", "ir", "is", "ish", "ith", "l", "la", "le", "lin", "ma", "mal", "man",
    "mar", "na", "nah", "nal", "nan", "ne", "neh", "nir", "ra", "rah", "ral", "ran", "re",
    "reh", "ri", "rin", "sa", "sal", "san", "se", "sel", "sha", "shal", "shan", "she", "shen",
    "si", "sin", "ta", "tal", "tan", "te", "tel", "ti", "tin", "va", "val", "van", "ve", "vel",
    "vi", "vin", "ya", "yah", "yal", "yan", "ye", "yel", "yi", "yin", "za", "zal", "zan", "ze",
    "zel", "zi", "zin"
]

male_prefix = [
    "ba", "bal", "bek", "bo", "bor", "bro", "dar", "del", "dra", "en", "er", "far", "fel", "gol",
    "gra", "ha", "har", "ho", "hor", "kar", "kel", "kor", "ku", "kur", "lar", "lek", "lok", "ma",
    "mar", "mo", "mor", "nar", "nel", "nor", "o", "or", "ra", "ran", "ro", "ron", "sa", "sar",
    "so", "sor", "ta", "tar", "to", "tor", "ur", "us", "va", "var", "vo", "vor"
]

male_suffix = [
    "ak", "ar", "ek", "el", "en", "er", "ik", "ir", "is", "ith", "ok", "or", "os", "oth", "uk",
    "ul", "un", "ur", "us", "uth", "yk", "yr", "ys"
]


surname_prefix = [
    "an", "bak", "blak", "bol", "bran", "bruk", "dar", "del", "dor", "erik", "fel", "gol", "grak",
    "gul", "har", "hel", "hor", "jor", "kar", "kel", "kha", "kol", "kor", "krul", "kul", "lar",
    "lek", "mor", "mur", "nal", "nul", "phel", "por", "rak", "ruk", "sar", "sel", "sol", "tar",
    "tel", "thel", "tol", "tor", "ul", "vak", "val", "var", "ver", "vol", "vor", "wol", "yor", "zol"
]

# Harry Potter-based surname suffixes
surname_suffix = [
    "aak", "ak", "an", "ar", "ek", "en", "er", "ik", "in", "ir", "ok", "on", "ong", "or", "uk", "un", "ur"
]

female = generate_female_name(female_prefix, female_suffix, min=0, max=1)
male = generate_male_name(male_prefix, male_suffix, min=0, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)



from supportive_functions import generate_female_name, generate_male_name, generate_surname_less


female_prefix = [
    "ai", "an", "bo", "chi", "da", "en", "fu", "go", "ha", "hi", "i", "ka", "ko", "mi", "na",
    "no", "ra", "ri", "sa", "shi", "ta", "to", "tsu", "u", "ya", "yo", "zu"
]

female_suffix = [
    "a", "aki", "ami", "aya", "chi", "e", "emi", "hana", "i", "iko", "ka", "kami", "ko", "mi",
    "miko", "na", "nami", "no", "omi", "ra", "ri", "saki", "shi", "ta", "to", "tsuki", "u", "ya",
    "yo"
]

male_prefix = [
    "ai", "ben", "chan", "da", "en", "fu", "gen", "hai", "ich", "ji", "ken", "li", "ming",
    "nao", "ori", "po", "qing", "ren", "shen", "tai", "ui", "vui", "wen", "xi", "ya", "zen"
]

male_suffix = [
    "bo", "chi", "do", "en", "fu", "gi", "hiro", "i", "ji", "ko", "lei", "ming", "no", "ou",
    "po", "quan", "rong", "shi", "to", "ui", "vui", "wen", "xi", "yo", "zen"
]

surname_prefix =  [
    "chin", "da", "fu", "guan", "han", "jing", "li", "mei", "ning", "qian", "rong", "shen", "ting",
    "wan", "xi", "yan", "zhi"
]

surname_suffix = [
    "bai", "chun", "feng", "hua", "ji", "lan", "mei", "nan", "ping", "qi", "rong", "shu", "ting",
    "wen", "xi", "yan", "ying", "zhi"
]
female = generate_female_name(female_prefix, female_suffix, min=1, max=2)
male = generate_male_name(male_prefix, male_suffix, min=1, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)


from supportive_functions import generate_female_name, generate_male_name, generate_surname_less


female_prefix = [
    "aer", "ash", "bri", "cer", "daen", "ela", "for", "gwe", "hel", "iri", "jen", "kal", "lyn",
    "mel", "ny", "oth", "pae", "qua", "rin", "san", "the", "uil", "val", "wyr", "xan", "yen", "zoe"
]

female_suffix = [
    "a", "ah", "ara", "beth", "cia", "dra", "elle", "fira", "ga", "hanna", "ia", "jara", "kara",
    "lyn", "ma", "na", "ora", "phine", "qua", "ra", "selle", "thya", "ura", "vira", "wyn", "ya", "zara"
]

male_prefix = [
    "aeg", "bar", "ben", "bran", "daen", "dav", "edd", "gar", "jaq", "jon", "khal", "lor", "mor", "ned",
    "qua", "rob", "sam", "theon", "tor", "tyr", "vis"
]

male_suffix = [
    "ard", "as", "dor", "en", "erion", "frey", "gar", "gold", "gon", "hard", "is", "jen", "lan", "len",
    "man", "mar", "men", "mond", "nard", "on", "or", "red", "rick", "ros", "sen", "son", "ton", "ton",
    "ver", "win"
]

surname_prefix = [
    "bar", "bel", "black", "bran", "bron", "cor", "dor", "grey", "har", "kar", "lan", "lor", "mor",
    "nor", "red", "rey", "sta", "star", "tar", "thor", "tyr", "var", "vel", "west", "win",
    "ar", "ber", "cad", "con", "dorn", "dur", "fay", "gar", "hol", "jor", "karl", "ly", "mal", "nar",
    "ran", "ren", "san", "sel", "thorn", "ven", "ver", "war", "wil", "ya", "yor", "zor"
]

surname_suffix = [
    "borne", "croft", "dale", "field", "ford", "gate", "helm", "hold", "horn", "keep", "lock",
    "ridge", "rock", "run", "shaw", "stead", "stone", "wall", "water", "well", "wood",
    "ark", "crest", "don", "ford", "glen", "ham", "hart", "holt", "land", "mont", "more", "port",
    "rick", "sage", "shire", "son", "ton", "ville", "ward", "wick", "wood", "worth", "wyn", "yard",
    "zell"
]

female = generate_female_name(female_prefix, female_suffix, min=0, max=2)
male = generate_male_name(male_prefix, male_suffix, min=0, max=2)
surname = generate_surname_less(surname_prefix, surname_suffix)
